<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="gl_ES">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Aplicativo de Proxy</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipo de proxy</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Enderezo IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requirido</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porto</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de usuario</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Opcional</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasinal</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Comprobe &quot;Usar un proxy&quot; no menú contextual da aplicación en Launcher despois de configurar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Gardar</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Enderezo IP non válido</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Porto inválido</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Desconectar</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Gardar</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectando</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Desconectar</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Está seguro de que quere eliminar esta configuración?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Conexión por cable% 1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Punto de acceso</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Conexión sen fíos% 1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>Conexión PPPoE% 1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>Nova VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>Tipo da VPN</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN% 1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan% 1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect% 1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Aplicativo de Proxy</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Punto de acceso persoal</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Detalles da rede</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Proxy do sistema</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Rede con fíos</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rede sen fíos</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Adaptador de rede con fíos</translation>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Engadir unha conexión de rede</translation>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Adaptador da rede sen fíos</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Conectar a unha rede oculta</translation>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-contents_path>/network/DSL</extra-contents_path>
        <extra-child_page_hide>DSL</extra-child_page_hide>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Crear conexión PPPoE</translation>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
        <extra-child_page>DSL</extra-child_page>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>Estado da VPN</translation>
        <extra-contents_path>/network/VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Crear VPN</translation>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importar VPN</translation>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipo de proxy</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL de configuración</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Enderezo IP</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Port</source>
        <translation>Porto</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de usuario</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasinal</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Punto de acceso</translation>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>Crear punto de acceso</translation>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interface</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Pasarela</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS primario</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de rede</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefixo</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocidade</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>Enderezo DNS non válido</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Non vinculante</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Enderezo MAC do dispositivo</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Enderezo MAC clonado</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Personalizar o MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Xeral</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requirido</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Xeral</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>O nome xa existe</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requirido</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Conectar automaticamente</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Punto de acceso</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Engadir configuración</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>Crear punto de acceso</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>Enderezo IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requirido</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Pasarela</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Enderezo IP non válido</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Máscara de rede non válida</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Pasarela non válida</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de rede</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requirido</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Enderezo IP non válido</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Pasarela non válida</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefixo</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto.</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorar</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Enderezo IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requirido</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Pasarela</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Só se aplica nos recursos correspondentes</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Método</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de rede</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefixo</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Enderezo IP non válido</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Máscara de rede non válida</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Pasarela non válida</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Método</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto.</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorar</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Detalles da rede</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Proxy do sistema</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Aplicativo de Proxy</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Detalles da rede</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desactivado</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto.</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>Configurar por Xestión da rede</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Punto de acceso persoal</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de usuario</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requirido</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Servizo</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasinal</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Rexeitar autenticación EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Rexeitar autenticación PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Rexeitar autenticación CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Rexeitar autenticación MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Rexeitar autenticación MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Sen compresión de datos BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Sen compresión de datos Deflate</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Sen compresión da cabeceira TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Sen compresión no campo protocolo</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Sen compresión enderezo/control</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Enviar paquetes echo PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Empregar MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bit MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE con estado</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Crear conexión PPPoE</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Proxy do sistema</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Gardar</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipo de proxy</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto.</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Opcional</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porto</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>Proxy HTTP</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>Proxy HTTPS</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>Proxy FTP</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>Proxy SOCKS</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Ignorar as configuracións do proxy para os servidores e dominios de arriba</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL de configuración</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Seguridade</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>RÁPIDO</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>EAP protexido</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Gardar contrasinal para este usuario</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Garda o contrasinal para todos os usuarios</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Pregúnteme sempre</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desactivado</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anónima</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Autenticado</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Ambos</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatico</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Versión 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Versión 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>Autenticación EAP</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identidade</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requirido</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opcións Pwd</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Chave privada</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificado CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificado de usuario</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>ID Anónimo</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Aprovisionamento</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>ficheiro PAC</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Autenticación Interna</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>Versión PEAP</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Contrasinal privado</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasinal</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Contrasinal inválido</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ningún</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Persoal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>Seguridade</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requirido</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Chave</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasinal</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Seguridade requirida</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Contrasinal inválido</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ningún</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Persoal</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Empresarial</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Clave compartida</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Abrir sistema</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Seguridade</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requirido</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autentificación</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Chave</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasinal</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Avanzado</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Configurar o porto da pasarela</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Porto da pasarela</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Configurar o intervalo do renegociado</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Intervalo do renegociado</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Use LZO Compresión de datos</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Use a conexión TCP</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Usar o dispositivo TAP</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Configurar o túnel MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Configurar o tamaño do fragmento UDP</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>Tamaño do fragmento UDP</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Restrinxir o túnel TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Aleatorizar Hosts remotos</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Avanzado</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (predefinido)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Seguro (predefinido)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Débil</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ningún</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T cando estea dispoñible (predefinido)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>Sempre NAT-T</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desactivado</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Grupo 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Grupo 2 (predefinido)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Grupo 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Servidor (predefinido)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DG Grupo 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Dominio</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Distribuidor</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versión</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Cifrado</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>Modo Traversal NAT</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>Grupo de IKE DH</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Confidencialidade directa</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Porto local</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Deshabilitar detección de portos mortos</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Activar IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Nome do grupo</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>ID do grupo</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Chave precompartida</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Fase 1 Algoritmos</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Fase 2 Algoritmos</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Pasarela non válida</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Pasarela</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requirido</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificado CA</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Permitir o troiano &apos;Cisco Secure Desktop&apos;</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>Script CSD</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificado de usuario</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Chave privada</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Empregar FSID como contrasinal da chave</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Pasarela non válida</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Certificados (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasinal</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Certificados con contrasinal (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Chave estática</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Gardado</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Preguntar</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Non requirido</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Pasarela</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requirido</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Tipo de autenticación</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificado CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificado de usuario</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Chave privada</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opcións Pwd</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Contrasinal privado</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de usuario</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Personalizar Dirección de Chaves</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Dirección da chave</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>IP remoto</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>IP local</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Todos dispoñibles (por defecto)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (menos segura)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (máis segura)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Rexeitar autenticación EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Rexeitar autenticación PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Rexeitar autenticación CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Rexeitar autenticación MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Rexeitar autenticación MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Sen compresión de datos BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Sen compresión de datos Deflate</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Sen compresión da cabeceira TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Sen compresión no campo protocolo</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Sen compresión enderezo/control</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Enviar paquetes echo PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Empregar MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Seguridade</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE con estado</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>Estado da VPN</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Crear VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importar VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Importar erros</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Erro do ficheiro</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>Proxy VPN</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Non requirido</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipo de proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP do servidor</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requirido</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porto</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Tentar indefinidamente cando falle</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de usuario</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasinal</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>Ficheiro CA</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Ignore os avisos do certificado</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>Use extensións de nome de host TLS</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>Seguridade VPN</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Predefinido</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ningún</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Cipher</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>Autenticación HMAC</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Pasarela non válida</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Gardado</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Preguntar</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Non requirido</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Pasarela</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requirido</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de usuario</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opcións Pwd</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasinal</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>Dominio NT</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>Proxy VPN</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP do servidor</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porto</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de usuario</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasinal</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Pasarela non válida</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Chave privada</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>Axente SSH</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Tarxeta intelixente</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Chave precompartida</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Pasarela</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requirido</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificado CA</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Tipo de autenticación</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificado de usuario</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de usuario</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasinal</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Solicitar un enderezo IP interno</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Forzar Encapsulación UDP</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Empregar Compresión IP</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Activa as propostas de cifrado personalizado</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>Autenticación TLS VPN</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Predefinido</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Cliente</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Servidor</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Emparellar temas</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Tipo de Certificado Remoto</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Ficheiro Clave</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Personalizar Dirección de Chaves</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Dirección da chave</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Pasarela non válida</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Gardado</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Preguntar</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Non requirido</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Pasarela</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requirido</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de usuario</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opcións Pwd</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasinal</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Nome do grupo</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Contrasinal do grupo</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Empregar autenticación híbrida</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>Ficheiro CA</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Primeiro, enchúfao á rede</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Adaptador de rede con fíos</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Engadir unha conexión de rede</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Seleccionar Configuración</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Adaptador da rede sen fíos</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Pechar un punto de acceso</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Desactive o punto de acceso primeiro se desexa conectarse a unha rede sen fíos</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Conectar a unha rede oculta</translation>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
        <extra-child_page>WirelessPage</extra-child_page>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Non vinculante</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requirido</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Enderezo MAC do dispositivo</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Personalizar o MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
</TS>